# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'roomdata_window.ui'
#
# Created by: PyQt5 UI code generator 5.15.7
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1185, 1085)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.label_opened_files = QtWidgets.QLabel(self.centralwidget)
        self.label_opened_files.setObjectName("label_opened_files")
        self.verticalLayout.addWidget(self.label_opened_files)
        self.opened_files_widget = QtWidgets.QListWidget(self.centralwidget)
        self.opened_files_widget.setObjectName("opened_files_widget")
        self.verticalLayout.addWidget(self.opened_files_widget)
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        self.label_2.setObjectName("label_2")
        self.verticalLayout.addWidget(self.label_2)
        self.excel_header_widget = QtWidgets.QListWidget(self.centralwidget)
        self.excel_header_widget.setObjectName("excel_header_widget")
        self.verticalLayout.addWidget(self.excel_header_widget)
        self.horizontalLayout_7.addLayout(self.verticalLayout)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.open_rule_btn = QtWidgets.QPushButton(self.centralwidget)
        self.open_rule_btn.setObjectName("open_rule_btn")
        self.horizontalLayout.addWidget(self.open_rule_btn)
        self.save_rule_btn = QtWidgets.QPushButton(self.centralwidget)
        self.save_rule_btn.setObjectName("save_rule_btn")
        self.horizontalLayout.addWidget(self.save_rule_btn)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.add_rule_btn = QtWidgets.QPushButton(self.centralwidget)
        self.add_rule_btn.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/icons/plus.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.add_rule_btn.setIcon(icon)
        self.add_rule_btn.setObjectName("add_rule_btn")
        self.horizontalLayout_2.addWidget(self.add_rule_btn)
        self.remove_rule_btn = QtWidgets.QPushButton(self.centralwidget)
        self.remove_rule_btn.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/icons/minus.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.remove_rule_btn.setIcon(icon1)
        self.remove_rule_btn.setObjectName("remove_rule_btn")
        self.horizontalLayout_2.addWidget(self.remove_rule_btn)
        self.edit_rule_btn = QtWidgets.QPushButton(self.centralwidget)
        self.edit_rule_btn.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icons/icons/edit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.edit_rule_btn.setIcon(icon2)
        self.edit_rule_btn.setObjectName("edit_rule_btn")
        self.horizontalLayout_2.addWidget(self.edit_rule_btn)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        self.rules_widget = QtWidgets.QListWidget(self.centralwidget)
        self.rules_widget.setObjectName("rules_widget")
        self.verticalLayout_2.addWidget(self.rules_widget)
        self.horizontalLayout_7.addLayout(self.verticalLayout_2)
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setText("")
        self.label.setPixmap(QtGui.QPixmap(":/icons/icons/arrow.png"))
        self.label.setObjectName("label")
        self.horizontalLayout_7.addWidget(self.label)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.rule_detail_widget = QtWidgets.QListWidget(self.centralwidget)
        self.rule_detail_widget.setObjectName("rule_detail_widget")
        self.verticalLayout_3.addWidget(self.rule_detail_widget)
        self.horizontalLayout_7.addLayout(self.verticalLayout_3)
        self.horizontalLayout_7.setStretch(0, 3)
        self.horizontalLayout_7.setStretch(1, 3)
        self.horizontalLayout_7.setStretch(3, 3)
        self.verticalLayout_7.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.start_process_btn = QtWidgets.QPushButton(self.centralwidget)
        self.start_process_btn.setObjectName("start_process_btn")
        self.horizontalLayout_3.addWidget(self.start_process_btn)
        self.start_date_edit = QtWidgets.QDateEdit(self.centralwidget)
        self.start_date_edit.setObjectName("start_date_edit")
        self.horizontalLayout_3.addWidget(self.start_date_edit)
        self.label_4 = QtWidgets.QLabel(self.centralwidget)
        self.label_4.setText("")
        self.label_4.setPixmap(QtGui.QPixmap(":/icons/icons/arrow.png"))
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_3.addWidget(self.label_4)
        self.end_date_edit = QtWidgets.QDateEdit(self.centralwidget)
        self.end_date_edit.setObjectName("end_date_edit")
        self.horizontalLayout_3.addWidget(self.end_date_edit)
        self.horizontalLayout_3.setStretch(0, 8)
        self.verticalLayout_7.addLayout(self.horizontalLayout_3)
        self.verticalLayout_7.setStretch(0, 10)
        self.verticalLayout_4.addLayout(self.verticalLayout_7)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1185, 26))
        self.menubar.setObjectName("menubar")
        self.menu = QtWidgets.QMenu(self.menubar)
        self.menu.setObjectName("menu")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionopen_file = QtWidgets.QAction(MainWindow)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/icons/icons/open.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionopen_file.setIcon(icon3)
        self.actionopen_file.setObjectName("actionopen_file")
        self.actionopen_dir = QtWidgets.QAction(MainWindow)
        self.actionopen_dir.setIcon(icon3)
        self.actionopen_dir.setObjectName("actionopen_dir")
        self.menu.addAction(self.actionopen_file)
        self.menu.addAction(self.actionopen_dir)
        self.menubar.addAction(self.menu.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.label_opened_files.setText(_translate("MainWindow", "已打开文件"))
        self.label_2.setText(_translate("MainWindow", "表头"))
        self.open_rule_btn.setText(_translate("MainWindow", "打开规则"))
        self.save_rule_btn.setText(_translate("MainWindow", "保存规则文件"))
        self.start_process_btn.setText(_translate("MainWindow", "开始处理"))
        self.menu.setTitle(_translate("MainWindow", "文件"))
        self.actionopen_file.setText(_translate("MainWindow", "打开文件"))
        self.actionopen_dir.setText(_translate("MainWindow", "打开目录"))
import images_rc
